"""
backend_statistic_chart automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_statistic_chart_data import BackendStatisticChartData
@dataclass_json
@dataclass
class BackendStatisticChart:
    labels: List[str] = field(default=None, metadata=config(field_name="labels"))
    data: List[BackendStatisticChartData] = field(default=None, metadata=config(field_name="data"))
    series: List[str] = field(default=None, metadata=config(field_name="series"))
