"""
consumer_grant automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
from .consumer_app import ConsumerApp
@dataclass_json
@dataclass
class ConsumerGrant:
    id: int = field(default=None, metadata=config(field_name="id"))
    app: ConsumerApp = field(default=None, metadata=config(field_name="app"))
    create_date: datetime.datetime = field(default=None, metadata=config(field_name="createDate"))
