"""
system_o_auth_configuration automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class SystemOAuthConfiguration:
    issuer: str = field(default=None, metadata=config(field_name="issuer"))
    token_endpoint: str = field(default=None, metadata=config(field_name="token_endpoint"))
    token_endpoint_auth_methods_supported: List[str] = field(default=None, metadata=config(field_name="token_endpoint_auth_methods_supported"))
    userinfo_endpoint: str = field(default=None, metadata=config(field_name="userinfo_endpoint"))
    scopes_supported: List[str] = field(default=None, metadata=config(field_name="scopes_supported"))
    claims_supported: List[str] = field(default=None, metadata=config(field_name="claims_supported"))
