"""
backend_identity_index_entry automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendIdentityIndexEntry:
    name: str = field(default=None, metadata=config(field_name="name"))
    _class: str = field(default=None, metadata=config(field_name="class"))
