"""
common_message automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class CommonMessage:
    success: bool = field(default=None, metadata=config(field_name="success"))
    message: str = field(default=None, metadata=config(field_name="message"))
    id: str = field(default=None, metadata=config(field_name="id"))
