"""
backend_page_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_page import BackendPage
@dataclass_json
@dataclass
class BackendPageCreate(BackendPage):
