"""
system_route automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .system_route_path import SystemRoutePath
@dataclass_json
@dataclass
class SystemRoute:
    routes: SystemRoutePath = field(default=None, metadata=config(field_name="routes"))
