"""
backend_dashboard automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_statistic_chart import BackendStatisticChart
from .backend_dashboard_apps import BackendDashboardApps
from .backend_dashboard_requests import BackendDashboardRequests
from .backend_dashboard_users import BackendDashboardUsers
from .backend_dashboard_transactions import BackendDashboardTransactions
@dataclass_json
@dataclass
class BackendDashboard:
    errors_per_operation: BackendStatisticChart = field(default=None, metadata=config(field_name="errorsPerOperation"))
    incoming_requests: BackendStatisticChart = field(default=None, metadata=config(field_name="incomingRequests"))
    incoming_transactions: BackendStatisticChart = field(default=None, metadata=config(field_name="incomingTransactions"))
    most_used_operations: BackendStatisticChart = field(default=None, metadata=config(field_name="mostUsedOperations"))
    time_per_operation: BackendStatisticChart = field(default=None, metadata=config(field_name="timePerOperation"))
    latest_apps: BackendDashboardApps = field(default=None, metadata=config(field_name="latestApps"))
    latest_requests: BackendDashboardRequests = field(default=None, metadata=config(field_name="latestRequests"))
    latest_users: BackendDashboardUsers = field(default=None, metadata=config(field_name="latestUsers"))
    latest_transactions: BackendDashboardTransactions = field(default=None, metadata=config(field_name="latestTransactions"))
