"""
backend_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendPlan:
    id: int = field(default=None, metadata=config(field_name="id"))
    name: str = field(default=None, metadata=config(field_name="name"))
    description: str = field(default=None, metadata=config(field_name="description"))
    price: float = field(default=None, metadata=config(field_name="price"))
    points: int = field(default=None, metadata=config(field_name="points"))
    period: int = field(default=None, metadata=config(field_name="period"))
    external_id: str = field(default=None, metadata=config(field_name="externalId"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
