"""
CommonMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from .common_message import CommonMessage

class CommonMessageException(sdkgen.KnownStatusCodeException):
    def __init__(self, payload):
        self.payload = CommonMessage.from_json(payload)

    pass

    def get_payload(self) -> CommonMessage:
        return self.payload

    pass
