"""
consumer_app_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class ConsumerAppUpdate:
    name: str = field(default=None, metadata=config(field_name="name"))
    url: str = field(default=None, metadata=config(field_name="url"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
