"""
backend_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_operation_parameters import BackendOperationParameters
from .backend_operation_throws import BackendOperationThrows
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendOperation:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    active: bool = field(default=None, metadata=config(field_name="active"))
    public: bool = field(default=None, metadata=config(field_name="public"))
    stability: int = field(default=None, metadata=config(field_name="stability"))
    description: str = field(default=None, metadata=config(field_name="description"))
    http_method: str = field(default=None, metadata=config(field_name="httpMethod"))
    http_path: str = field(default=None, metadata=config(field_name="httpPath"))
    http_code: int = field(default=None, metadata=config(field_name="httpCode"))
    name: str = field(default=None, metadata=config(field_name="name"))
    parameters: BackendOperationParameters = field(default=None, metadata=config(field_name="parameters"))
    incoming: str = field(default=None, metadata=config(field_name="incoming"))
    outgoing: str = field(default=None, metadata=config(field_name="outgoing"))
    throws: BackendOperationThrows = field(default=None, metadata=config(field_name="throws"))
    action: str = field(default=None, metadata=config(field_name="action"))
    costs: int = field(default=None, metadata=config(field_name="costs"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
