"""
backend_identity_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_identity_index_entry import BackendIdentityIndexEntry
@dataclass_json
@dataclass
class BackendIdentityIndex:
    providers: List[BackendIdentityIndexEntry] = field(default=None, metadata=config(field_name="providers"))
