"""
common_form_element automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class CommonFormElement:
    element: str = field(default=None, metadata=config(field_name="element"))
    name: str = field(default=None, metadata=config(field_name="name"))
    title: str = field(default=None, metadata=config(field_name="title"))
    help: str = field(default=None, metadata=config(field_name="help"))
