"""
backend_config_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_config import BackendConfig
@dataclass_json
@dataclass
class BackendConfigUpdate(BackendConfig):
