"""
common_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class CommonCollection:
    total_results: int = field(default=None, metadata=config(field_name="totalResults"))
    start_index: int = field(default=None, metadata=config(field_name="startIndex"))
    items_per_page: int = field(default=None, metadata=config(field_name="itemsPerPage"))
    entry: List[T] = field(default=None, metadata=config(field_name="entry"))
