"""
backend_user_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_user import BackendUser
@dataclass_json
@dataclass
class BackendUserCreate(BackendUser):
    password: str = field(default=None, metadata=config(field_name="password"))
