"""
backend_connection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_connection_config import BackendConnectionConfig
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendConnection:
    id: int = field(default=None, metadata=config(field_name="id"))
    name: str = field(default=None, metadata=config(field_name="name"))
    _class: str = field(default=None, metadata=config(field_name="class"))
    config: BackendConnectionConfig = field(default=None, metadata=config(field_name="config"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
