"""
backend_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
@dataclass_json
@dataclass
class BackendWebhookResponse:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    code: int = field(default=None, metadata=config(field_name="code"))
    attempts: int = field(default=None, metadata=config(field_name="attempts"))
    error: str = field(default=None, metadata=config(field_name="error"))
    execute_date: datetime.datetime = field(default=None, metadata=config(field_name="executeDate"))
