"""
backend_scope_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendScopeOperation:
    operation_id: int = field(default=None, metadata=config(field_name="operationId"))
    allow: bool = field(default=None, metadata=config(field_name="allow"))
