"""
backend_config automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import Any
@dataclass_json
@dataclass
class BackendConfig:
    id: int = field(default=None, metadata=config(field_name="id"))
    type: int = field(default=None, metadata=config(field_name="type"))
    name: str = field(default=None, metadata=config(field_name="name"))
    description: str = field(default=None, metadata=config(field_name="description"))
    value: Any = field(default=None, metadata=config(field_name="value"))
