"""
backend_statistic_chart_data automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import Any
from typing import Dict
class BackendStatisticChartData(Dict[str, Any]):
    pass
