"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .consumer_authorize_response_token import ConsumerAuthorizeResponseToken
@dataclass_json
@dataclass
class ConsumerAuthorizeResponse:
    type: str = field(default=None, metadata=config(field_name="type"))
    token: ConsumerAuthorizeResponseToken = field(default=None, metadata=config(field_name="token"))
    code: str = field(default=None, metadata=config(field_name="code"))
    redirect_uri: str = field(default=None, metadata=config(field_name="redirectUri"))
