"""
backend_dashboard_requests automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_collection import CommonCollection
from .backend_dashboard_request import BackendDashboardRequest
@dataclass_json
@dataclass
class BackendDashboardRequests(CommonCollection[BackendDashboardRequest]):
    pass
