"""
system_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .system_schema_type_schema import SystemSchemaTypeSchema
from .system_schema_form import SystemSchemaForm
@dataclass_json
@dataclass
class SystemSchema:
    schema: SystemSchemaTypeSchema = field(default=None, metadata=config(field_name="schema"))
    form: SystemSchemaForm = field(default=None, metadata=config(field_name="form"))
