"""
backend_operation_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_operation import BackendOperation
@dataclass_json
@dataclass
class BackendOperationCreate(BackendOperation):
