"""
common_metadata automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import Dict
class CommonMetadata(Dict[str, str]):
    pass
