"""
backend_action_execute_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_action_execute_request_body import BackendActionExecuteRequestBody
@dataclass_json
@dataclass
class BackendActionExecuteRequest:
    method: str = field(default=None, metadata=config(field_name="method"))
    uri_fragments: str = field(default=None, metadata=config(field_name="uriFragments"))
    parameters: str = field(default=None, metadata=config(field_name="parameters"))
    headers: str = field(default=None, metadata=config(field_name="headers"))
    body: BackendActionExecuteRequestBody = field(default=None, metadata=config(field_name="body"))
