"""
backend_dashboard_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
@dataclass_json
@dataclass
class BackendDashboardTransaction:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: str = field(default=None, metadata=config(field_name="status"))
    provider: str = field(default=None, metadata=config(field_name="provider"))
    transaction_id: str = field(default=None, metadata=config(field_name="transactionId"))
    amount: float = field(default=None, metadata=config(field_name="amount"))
    date: datetime.datetime = field(default=None, metadata=config(field_name="date"))
