"""
backend_log_error automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendLogError:
    id: int = field(default=None, metadata=config(field_name="id"))
    message: int = field(default=None, metadata=config(field_name="message"))
    trace: str = field(default=None, metadata=config(field_name="trace"))
    file: str = field(default=None, metadata=config(field_name="file"))
    line: int = field(default=None, metadata=config(field_name="line"))
