"""
backend_backup_import_result automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class BackendBackupImportResult:
    success: bool = field(default=None, metadata=config(field_name="success"))
    message: str = field(default=None, metadata=config(field_name="message"))
    logs: List[str] = field(default=None, metadata=config(field_name="logs"))
