"""
backend_connection_introspection_entity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_connection_introspection_entity_row import BackendConnectionIntrospectionEntityRow
@dataclass_json
@dataclass
class BackendConnectionIntrospectionEntity:
    name: str = field(default=None, metadata=config(field_name="name"))
    headers: List[str] = field(default=None, metadata=config(field_name="headers"))
    rows: List[BackendConnectionIntrospectionEntityRow] = field(default=None, metadata=config(field_name="rows"))
