"""
consumer_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .consumer_webhook_response import ConsumerWebhookResponse
@dataclass_json
@dataclass
class ConsumerWebhook:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    event: str = field(default=None, metadata=config(field_name="event"))
    name: str = field(default=None, metadata=config(field_name="name"))
    endpoint: str = field(default=None, metadata=config(field_name="endpoint"))
    responses: List[ConsumerWebhookResponse] = field(default=None, metadata=config(field_name="responses"))
