"""
backend_rate automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_rate_allocation import BackendRateAllocation
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendRate:
    id: int = field(default=None, metadata=config(field_name="id"))
    priority: int = field(default=None, metadata=config(field_name="priority"))
    name: str = field(default=None, metadata=config(field_name="name"))
    rate_limit: int = field(default=None, metadata=config(field_name="rateLimit"))
    timespan: datetime.timedelta = field(default=None, metadata=config(field_name="timespan"))
    allocation: List[BackendRateAllocation] = field(default=None, metadata=config(field_name="allocation"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
