"""
consumer_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
import datetime
@dataclass_json
@dataclass
class ConsumerToken:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    name: str = field(default=None, metadata=config(field_name="name"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    ip: str = field(default=None, metadata=config(field_name="ip"))
    expire: datetime.date = field(default=None, metadata=config(field_name="expire"))
    date: datetime.datetime = field(default=None, metadata=config(field_name="date"))
