"""
consumer_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerWebhookResponse:
    status: int = field(default=None, metadata=config(field_name="status"))
    code: int = field(default=None, metadata=config(field_name="code"))
    attempts: str = field(default=None, metadata=config(field_name="attempts"))
    execute_date: str = field(default=None, metadata=config(field_name="executeDate"))
