"""
backend_operation_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendOperationSchema:
    description: str = field(default=None, metadata=config(field_name="description"))
    type: str = field(default=None, metadata=config(field_name="type"))
    format: str = field(default=None, metadata=config(field_name="format"))
    enum: str = field(default=None, metadata=config(field_name="enum"))
