"""
backend_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_schema_source import BackendSchemaSource
from .backend_schema_form import BackendSchemaForm
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendSchema:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    name: str = field(default=None, metadata=config(field_name="name"))
    source: BackendSchemaSource = field(default=None, metadata=config(field_name="source"))
    form: BackendSchemaForm = field(default=None, metadata=config(field_name="form"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
