"""
backend_statistic_count automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
@dataclass_json
@dataclass
class BackendStatisticCount:
    count: int = field(default=None, metadata=config(field_name="count"))
    _from: datetime.datetime = field(default=None, metadata=config(field_name="from"))
    to: datetime.datetime = field(default=None, metadata=config(field_name="to"))
