"""
consumer_token_access_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerTokenAccessToken:
    access_token: str = field(default=None, metadata=config(field_name="access_token"))
    token_type: str = field(default=None, metadata=config(field_name="token_type"))
    expires_in: int = field(default=None, metadata=config(field_name="expires_in"))
    refresh_token: str = field(default=None, metadata=config(field_name="refresh_token"))
    scope: str = field(default=None, metadata=config(field_name="scope"))
