"""
consumer_page automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class ConsumerPage:
    id: int = field(default=None, metadata=config(field_name="id"))
    title: str = field(default=None, metadata=config(field_name="title"))
    slug: str = field(default=None, metadata=config(field_name="slug"))
    content: str = field(default=None, metadata=config(field_name="content"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
